# Generated by roxygen2: do not edit by hand

export(BSET)
export(Bayesian_test)
export(DGP_X_Gaussian)
export(DGP_X_binary)
export(DGP_no_X)
export(compute_BF_distribution)
export(compute_V_S_star)
export(compute_delta)
export(compute_estimands_Carlotti_and_Parast_2026)
export(compute_estimands_Parast_et_al_2024)
export(compute_theta)
export(frequentist_test)
importFrom(Rdpack,reprompt)
importFrom(SurrogateRank,test.surrogate)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(mvtnorm,rmvnorm)
importFrom(rlang,.data)
importFrom(stats,dbinom)
importFrom(stats,pbeta)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,uniroot)
importFrom(stats,wilcox.test)
